@@ -162,20 +162,18 @@ class AirbyteResource:
     def cancel_job(self, job_id: int):
         self.make_request(endpoint="/jobs/cancel", data={"id": job_id})
 
-    def get_default_workspace(self):
+    def get_default_workspace(self) -> str:
         workspaces = cast(
             List[Dict[str, Any]],
             check.not_none(self.make_request_cached(endpoint="/workspaces/list", data={})).get(
                 "workspaces", []
             ),
         )
-        return workspaces[0].get("workspaceId")
+        return workspaces[0]["workspaceId"]
 
-    def get_source_definition_by_name(self, name: str, workspace_id: str) -> Optional[str]:
+    def get_source_definition_by_name(self, name: str) -> Optional[str]:
         name_lower = name.lower()
-        definitions = self.make_request_cached(
-            endpoint="/source_definitions/list_for_workspace", data={"workspaceId": workspace_id}
-        )
+        definitions = self.make_request_cached(endpoint="/source_definitions/list", data={})
 
         return next(
             (
@@ -186,15 +184,12 @@ class AirbyteResource:
             None,
         )
 
-    def get_destination_definition_by_name(self, name: str, workspace_id: str):
+    def get_destination_definition_by_name(self, name: str):
         name_lower = name.lower()
         definitions = cast(
             Dict[str, List[Dict[str, str]]],
             check.not_none(
-                self.make_request_cached(
-                    endpoint="/destination_definitions/list_for_workspace",
-                    data={"workspaceId": workspace_id},
-                )
+                self.make_request_cached(endpoint="/destination_definitions/list", data={})
             ),
         )
         return next(
